@@ -316,7 +316,7 @@ extern "C" {
 }
 
 // logging & URL cache processes
-void log_listener(std::string log_location, bool logconerror, bool logsyslog);
+void log_listener(std::string log_location, bool logconerror, bool logsyslog, Queue<std::string>* log_Q);
 
 // fork off into background
 bool daemonise();
@@ -664,7 +664,7 @@ void wait_for_proxy()
 // *
 // *
 
-void log_listener(std::string log_location, bool logconerror, bool logsyslog) {
+void log_listener(std::string log_location, bool logconerror, bool logsyslog, Queue<std::string> *log_Q) {
     thread_id = "log: ";
     try {
 #ifdef DGDEBUG
@@ -737,7 +737,7 @@ void log_listener(std::string log_location, bool logconerror, bool logsyslog) {
 
     while (!logger_ttg) { // loop, essentially, for ever
         std::string loglines;
-        loglines.append(o.log_Q->pop());  // get logdata from queue
+        loglines.append(log_Q->pop());  // get logdata from queue
         if (logger_ttg) break;
 #ifdef DGDEBUG
         std::cerr << thread_id << "received a log request" <<  loglines << std::endl;
@@ -1579,13 +1579,22 @@ int fc_controlit()   //
     // Threads are created for logger, a separate thread for each listening port
     // and an array of worker threads to deal with the work.
     if (!o.no_logger) {
-        std::thread log_thread(log_listener, o.log_location, o.logconerror, o.log_syslog);
+        std::thread log_thread(log_listener, o.log_location, o.logconerror, o.log_syslog,o.log_Q);
         log_thread.detach();
 #ifdef DGDEBUG
     std::cerr << thread_id << "log_listener thread created" << std::endl;
 #endif
     }
 
+    if(o.log_requests) {
+        std::thread RQlog_thread(log_listener, o.RQlog_location, o.logconerror, false,o.RQlog_Q);
+        RQlog_thread.detach();
+#ifdef DGDEBUG
+        std::cerr << thread_id << "RQlog_listener thread created" << std::endl;
+#endif
+
+    }
+
 // I am the main thread here onwards.
 
 #ifdef DGDEBUG
@@ -1594,15 +1603,26 @@ int fc_controlit()   //
 
 
     sigset_t signal_set;
-    //pthread_t signal_thread_id;
-    struct timespec timeout;
-    int stat;
     sigemptyset(&signal_set);
-    //sigfillset(&signal_set);
     sigaddset(&signal_set, SIGHUP);
     sigaddset(&signal_set, SIGPIPE);
     sigaddset(&signal_set, SIGTERM);
     sigaddset(&signal_set, SIGUSR1);
+
+#ifdef __OpenBSD__
+    // OpenBSD does not support posix sig_timed_wait, so have to use timer and SIGALRM 
+    // set up timer for main loop
+    struct itimerval timeout;
+    timeout.it_interval.tv_sec = 0;
+    timeout.it_interval.tv_usec = (suseconds_t) 0;
+    timeout.it_value.tv_usec = (suseconds_t) 0;
+    sigaddset(&signal_set, SIGALRM);
+#else
+    struct timespec timeout;
+    timeout.tv_sec = 0;
+    timeout.tv_nsec = (long) 0;
+#endif
+    int stat;
     stat = pthread_sigmask(SIG_BLOCK, &signal_set, NULL);
     if (stat != 0) {
         syslog(LOG_ERR, "%sError setting sigmask", thread_id.c_str());
@@ -1694,8 +1714,40 @@ int fc_controlit()   //
             gentlereload = false;
             continue;        //  OK to continue even if gentle failed - just continue to use previous lists
         }
+#ifdef __OpenBSD__
+    // OpenBSD does not support posix sig_timed_wait, so have to use timer and SIGALRM 
+        timeout.it_value.tv_sec = 5;
+        setitimer(ITIMER_REAL, &timeout, NULL);
+        int rsig;
+        rc = sigwait(&signal_set, &rsig);
+        if (rc < 0) {
+            if (errno != EAGAIN) {
+                syslog(LOG_INFO, "%sUnexpected error from sigtimedwait() %d %s", thread_id.c_str(), errno, strerror(errno));
+            }
+        } else {
+            if (rsig == SIGUSR1)
+                gentlereload = true;
+            if (rsig == SIGTERM)
+                ttg = true;
+            if (rsig == SIGHUP)
+                gentlereload = true;
+            if (rsig != SIGALRM) {
+                // unset alarm
+                timeout.it_value.tv_sec = 0;
+                //timer_settime(timerid,0,&timeout, NULL);
+                setitimer(ITIMER_REAL, &timeout, NULL);
+
+#ifdef DGDEBUG
+                std::cerr << "signal:" << rc << std::endl;
+#endif
+                if (o.logconerror) {
+                    syslog(LOG_INFO, "%ssigtimedwait() signal %d recd:", thread_id.c_str(), rsig);
+                }
+            }
+        }
+#else
+	// other posix compliant platforms
         timeout.tv_sec = 5;
-        timeout.tv_nsec = (long) 0;
         rc = sigtimedwait(&signal_set, NULL, &timeout);
         if (rc < 0) {
             if (errno != EAGAIN) {
@@ -1715,6 +1767,8 @@ int fc_controlit()   //
                 syslog(LOG_INFO, "%ssigtimedwait() signal %d recd:", thread_id.c_str(), rc);
             }
         }
+#endif   // end __OpenBSD__ else
+
         int q_size = o.http_worker_Q.size();
 #ifdef DGDEBUG
         std::cerr << thread_id << "busychildren:" << dystat->busychildren << " worker Q size:" << q_size << std::endl;
@@ -1771,6 +1825,9 @@ int fc_controlit()   //
     logger_ttg = true;
     std::string nullstr("");
     o.log_Q->push(nullstr);
+    if (o.log_requests) {
+        o.RQlog_Q->push(nullstr);
+    }
 
     if (o.logconerror) {
         syslog(LOG_INFO,"%sstopping any remaining connections", thread_id.c_str());
