@@ -59,6 +59,7 @@ bool ICAPHeader::setEncapRecs() {
         encap_recs.push_back(erec);
         t = t.after(", ");
     }
+    return true;
 }
 
 // reset header object for future use
@@ -145,7 +146,6 @@ int ICAPHeader::returnCode()    // does not apply to ICAP ?  May do if we use fo
 
 void ICAPHeader::checkheader(bool allowpersistent)
 {
-    bool outgoing = true;
     if (header.size() > 1) {
     for (std::deque<String>::iterator i = header.begin() + 1; i != header.end(); i++) { // check each line in the headers
         // index headers - try to perform the checks in the order the average browser sends the headers.
@@ -613,6 +613,7 @@ bool  ICAPHeader::errorResponse(Socket &peerconn, String &res_header, String &re
 
 void ICAPHeader::setClientIP(String &ip) {
     clientip = ip;
+    HTTPrequest.setClientIP(ip);
 }
 
 bool ICAPHeader::in(Socket *sock, bool allowpersistent)
