@@ -78,7 +78,7 @@ RegExp::RegExp(const RegExp &r)
 //    rs.results.clear();
     //nrs.offsets.clear();
     //nrs.lengths.clear();
-    unsigned int i;
+    //unsigned int i;
     //for (i = 0; i < rs.results.size(); i++) {
         //nrs.results.push_back(rs.results[i]);
     //}
@@ -159,7 +159,7 @@ bool RegExp::match(const char *text, RegResult &rs)
     rs.offsets.clear();
     rs.lengths.clear();
     rs.imatched = false;
-    int num_sub_expressions = MAX_SUB_EXPRESSIONS;
+    unsigned int num_sub_expressions = MAX_SUB_EXPRESSIONS;
     if (reg.re_nsub < num_sub_expressions)
         num_sub_expressions = reg.re_nsub;
     regmatch_t *pmatch = new regmatch_t[num_sub_expressions + 1]; // to hold result
@@ -172,9 +172,9 @@ bool RegExp::match(const char *text, RegResult &rs)
     if (regexec(&reg, pos, num_sub_expressions + 1, pmatch, 0)) { // run regexdelete[]pmatch;
         delete[] pmatch;
         rs.imatched = false;
-        //        #ifdef DGDEBUG
-        //            std::cerr << thread_id << "no match for:" << searchstring << std::endl;
-        //        #endif
+#ifdef REDEBUG
+            std::cerr << thread_id << "no match for:" << searchstring << std::endl;
+#endif
         return false; // if no match
     }
     size_t matchlen;
