@@ -21,6 +21,7 @@ HTTPHeader *reqheader;
 // GLOBALS
 
 extern OptionContainer o;
+extern thread_local std::string thread_id;
 String fname = "";
 
 // class name is relevant!
@@ -33,8 +34,9 @@ class headerinstance : public AuthPlugin
     	String fname(cv["header"]);
 	o.ident_header_value = fname;
         needs_proxy_query = true;
+        client_ip_based = false;
     };
-    int identify(Socket &peercon, Socket &proxycon, HTTPHeader &h, std::string &string);
+    int identify(Socket &peercon, Socket &proxycon, HTTPHeader &h, std::string &string, bool &is_real_user);
 };
 
 // IMPLEMENTATION
@@ -49,7 +51,7 @@ AuthPlugin *headercreate(ConfigVar &definition)
 // end of Class factory
 
 // proxy auth header username extraction
-int headerinstance::identify(Socket &peercon, Socket &proxycon, HTTPHeader &h, std::string &string)
+int headerinstance::identify(Socket &peercon, Socket &proxycon, HTTPHeader &h, std::string &string, bool &is_real_user)
 {
     if (fname.length() < 0) 
    	return DGAUTH_NOMATCH;
