@@ -13,6 +13,8 @@
 
 #include <syslog.h>
 
+extern thread_local std::string thread_id;
+
 // DECLARATIONS
 
 // class name is relevant!
@@ -23,6 +25,7 @@ class proxyinstance : public AuthPlugin
         : AuthPlugin(definition)
     {
         needs_proxy_query = true;
+        client_ip_based = false;
     };
     int identify(Socket &peercon, Socket &proxycon, HTTPHeader &h, std::string &string, bool &is_real_user);
 };
