@@ -50,6 +50,7 @@
 #endif
 
 OptionContainer o;
+thread_local std::string thread_id;
 
 bool is_daemonised;
 
@@ -171,7 +172,7 @@ int main(int argc, char *argv[])
                     std::cout << "  -r reloads lists and group config files by issuing a HUP," << std::endl;
                     std::cout << "     but this does not reset the httpworkers option (amongst others)." << std::endl;
                     std::cout << "  -g  same as -r  (Issues a USR1)" << std::endl;
-                    std::cout << "  -i read total block list from stdin" << std::endl;
+                    std::cout << "  -i read lists from stdin" << std::endl;
 #ifdef __BENCHMARK
                     std::cout << "  --bs benchmark searching filter group 1's bannedsitelist" << std::endl;
                     std::cout << "  --bu benchmark searching filter group 1's bannedurllist" << std::endl;
@@ -221,6 +222,12 @@ int main(int argc, char *argv[])
 #endif
     }
 
+    if(!o.createLists(0))  {
+        std::cerr << "Error reading filter group conf file(s)." << std::endl;
+        syslog(LOG_ERR, "%s", "Error reading filter group conf file(s).");
+        return 1;
+    }
+
 #ifdef __BENCHMARK
     // run benchmarks instead of starting the daemon
     if (benchmark) {
@@ -292,7 +299,7 @@ int main(int argc, char *argv[])
             DataBuffer d(file.c_str(), file.length());
             String f;
             n.checkme(&d, f, f);
-            std::cout << "What is naughty: "<< n.isItNaughty << std::endl
+            std::cout << n.isItNaughty << std::endl
                       << n.whatIsNaughty << std::endl
                       << n.whatIsNaughtyLog << std::endl
                       << n.whatIsNaughtyCategories << std::endl;
@@ -491,6 +498,7 @@ int main(int argc, char *argv[])
             syslog(LOG_ERR, "%s", "Exiting with error");
             return rc; // exit returning the error number
         }
-        return 0; // exit without error
+        if (is_daemonised)
+        	return 0; // exit without error
     }
 }
